# scheduledexecutor

[![CI](https://github.com/delegacy/scheduledexecutor/actions/workflows/ci.yml/badge.svg)](https://github.com/delegacy/scheduledexecutor/actions)
[![Codecov](https://codecov.io/gh/delegacy/scheduledexecutor/branch/main/graph/badge.svg?token=I6VQGPPOKF)](https://codecov.io/gh/delegacy/scheduledexecutor)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PyPI Package latest release](https://img.shields.io/pypi/v/scheduledexecutor.svg)](https://pypi.org/project/scheduledexecutor/)
[![PyPI Wheel](https://img.shields.io/pypi/wheel/scheduledexecutor.svg)](https://pypi.org/project/scheduledexecutor/)
[![Supported versions](https://img.shields.io/pypi/pyversions/scheduledexecutor.svg)](https://pypi.org/project/scheduledexecutor/)
[![License](https://img.shields.io/pypi/l/scheduledexecutor.svg)](https://pypi.org/project/scheduledexecutor/)
[![Documentation Status](https://readthedocs.org/projects/scheduledexecutor/badge/?version=latest)](https://scheduledexecutor.readthedocs.io/en/latest/?badge=latest)
